% ----------------------
% TE.m
% ----------------------
% computes the temporary equilibrium for the global time 't'
% in:   w
% out:  edl
% ----------------------

function edlresid = TE(wage)

global t rho sigma gam psi
global Y Div w theta I J V K H Omega Q C TB DF A edy r
global A_0 alpha LS LD edl ell N NB delta
global epsl parl0 parl1 parp0 epsp hcut part omega

w(t)    = wage;

% DEMOGRAPHY
N(t+1)  = gam(t+1)*N(t)+NB(t+1);

% LABOR SUPPLY
ell(t)   = (w(t)*theta(t)/parl0)^epsl;
dis_ell  = parl0*(epsl/(1+epsl))*ell(t)^((1+epsl)/epsl)-parl1;

% PARTICIPATION
hcut(t)  = w(t)*ell(t)*theta(t)-dis_ell-omega;
part(t)  = 1-hcut(t)^(-epsp)*parp0^epsp;
hexp     = 1/part(t)*epsp/(1+epsp)*(parp0^epsp*hcut(t)^(1-epsp)-parp0);
dis_tot  = part(t)*dis_ell-(1-part(t))*(hexp+omega);

LS(t)    = part(t)*ell(t)*theta(t)*N(t);

% PRODUCTION
Y(t)    = A_0*K(t)^alpha*LS(t)^(1-alpha);
LD(t)   = ((1-alpha)*A_0/w(t))^(1/alpha)*K(t);

% INVESTMENT
a1      = psi/K(t);
a2      = (1-delta*psi)+(1-delta)*psi;
a3      = (1-delta)*(1-delta*psi)*K(t)-V(t+1)/(1+r(t+1));
I(t)    = (-a2+sqrt(a2^2-4*a1*a3))/(2*a1);
J(t)    = 1/2*psi*K(t)*(I(t)/K(t)-delta)^2;
K(t+1)  = I(t)+(1-delta)*K(t);

% FIRM VALUE
Div(t)  = Y(t)-w(t)*LD(t)-I(t)-J(t);
V(t)    = Div(t)+V(t+1)/(1+r(t+1));

% CONSUMPTION AND SAVINGS
Omega(t)= 1+(1/(1+rho))^sigma*(1+r(t+1))^(sigma-1)*gam(t+1)*Omega(t+1);
H(t)    = w(t)*LS(t)-dis_tot*N(t)+gam(t+1)*H(t+1)*(N(t)/N(t+1))/(1+r(t+1));
A(t)    = DF(t)+V(t);
Q(t)    = (H(t)+A(t))/Omega(t);
C(t)    = Q(t)+dis_tot*N(t);

TB(t)   = Y(t)-C(t)-I(t)-J(t);
DF(t+1) = (1+r(t+1))*(DF(t)+TB(t));
A(t+1)  = (1+r(t+1))*(A(t)+w(t)*LS(t)-C(t));

% EQUILIBRIUM
edy(t)  = I(t)+J(t)+C(t)+TB(t)-Y(t);
edl(t)  = LD(t)-LS(t);

edlresid = edl(t);

end

